==> dnv_bladed_models-0.3.32.tar.gz: dnv_bladed_models-0.3.32/src/dnv_bladed_models/applied_load.py <==
# coding: utf-8

from __future__ import annotations
from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra  # noqa: F401

from dnv_bladed_models.dnv import Dnv

from dnv_bladed_models.vector3_d import Vector3D


class AppliedLoad_AppliedLoadTypeEnum(str, Enum):
    TOWER_POINT_LOADING = "TowerPointLoading"
    BLADE_POINT_LOADING = "BladePointLoading"

class AppliedLoad(Dnv):
    """AppliedLoad - The common properties of a point loading time history.

    Attributes:
        - StartTime: float => A number representing a time.  The SI units for time are seconds.
        - LoadingFilepath: str => A filepath or URI containing one or six degree of loading data.  In the case of the six degrees of freedom, these will be applied in the component&#39;s coordinate system.  Where a single degree of freedom is provided, SingleDirectionLoading must also be specified.
        - DirectionOfLoading: Vector3D 
        - OnComponentInAssembly: str => This is a JSON $ref style reference to a component in the assembly tree.
        - AppliedLoadType: AppliedLoad_AppliedLoadTypeEnum => Allows the schema to identify the type of the object.
        
    This class is an abstraction, with the following concrete implementations:
        - BladePointLoading
        - TowerPointLoading
    """

    StartTime: Optional[float] = Field(alias="StartTime", default=None)
    LoadingFilepath: Optional[str] = Field(alias="LoadingFilepath", default=None)
    DirectionOfLoading: Optional[Vector3D] = Field(alias="DirectionOfLoading", default=None)
    OnComponentInAssembly: Optional[str] = Field(alias="OnComponentInAssembly", default=None)
    AppliedLoadType: Optional[AppliedLoad_AppliedLoadTypeEnum] = Field(alias="AppliedLoadType", default=None)

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass

    _subtypes_ = dict()

    def __init_subclass__(cls, AppliedLoadType=None):
        cls._subtypes_[AppliedLoadType or cls.__name__.lower()] = cls

    @classmethod
    def __get_validators__(cls):
        yield cls._convert_to_real_type_

    @classmethod
    def _convert_to_real_type_(cls, data: dict):
        if isinstance(data, dict):
            data_type = data.get("AppliedLoadType")

            if data_type is None:
                raise ValueError("Missing 'AppliedLoadType' in AppliedLoad")

            sub = cls._subtypes_.get(data_type)

            if sub is None:
                raise TypeError(f"Unsupported sub-type: '{data_type}' for base-type 'AppliedLoad'")

            return sub(**data)

        return data

    @root_validator(pre=True)
    def parsing_ignores_underscore_properties(cls, values: dict[str, any]):
        allowed_vals = {}
        for key, val in values.items():
            if not key.startswith('_'):
                if isinstance(val, dict):
                    allowed_child_vals = {}
                    for child_key, child_val in val.items():
                        if not child_key.startswith('_'):
                            allowed_child_vals[child_key] = child_val
                    allowed_vals[key] = allowed_child_vals
                else:
                    allowed_vals[key] = val
        return allowed_vals

    @validator("OnComponentInAssembly")
    def OnComponentInAssembly_pattern(cls, value):
        if value is not None and not re.match(r"^#(\/.+)+$", value):
            raise ValueError(f"OnComponentInAssembly did not match the expected format (found {value})")
        return value

    def to_json(
        self,
        *, 
        include: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        exclude: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        by_alias: bool = True, 
        skip_defaults: Optional[bool] = None, 
        exclude_unset: bool = False, 
        exclude_defaults: bool = False, 
        exclude_none: bool = True, 
        encoder: Optional[Callable[[Any], Any]] = None, 
        models_as_dict: bool = True, 
        **dumps_kwargs: Any) -> str:

        r"""
        Generates a JSON string representation of the model.
        
        Notes
        -----
        `include` and `exclude` arguments as per `dict()`.

        `encoder` is an optional function to supply as `default` to json.dumps(), other arguments as per `json.dumps()`.

        Examples
        --------
        >>> model.to_json()

        Renders the full JSON representation of the model object.
        """

        if dumps_kwargs.get('indent') is None:
            dumps_kwargs.update(indent=2)

        return super().json(
                include=include, 
                exclude=exclude, 
                by_alias=by_alias, 
                skip_defaults=skip_defaults, 
                exclude_unset=exclude_unset, 
                exclude_defaults=exclude_defaults, 
                exclude_none=exclude_none, 
                encoder=encoder, 
                models_as_dict=models_as_dict, 
                **dumps_kwargs)
    
    @classmethod
    def from_file(
        cls: Type['Model'],
        path: Union[str, Path]) -> 'Model':
        
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        AppliedLoad
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = AppliedLoad.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)
    
    @classmethod
    def from_json(
        cls: Type['Model'],
        b: StrBytes) -> 'Model':

        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        AppliedLoad
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = AppliedLoad.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
    
    @classmethod
    def from_dict(
        cls: Type['Model'],
         obj: Any) -> 'Model':

        r"""
        Creates a model object from a dict.

        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        AppliedLoad
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)
    
    def to_file(
        self,
        path: Union[str, Path]):

        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.        

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')

        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())

AppliedLoad.update_forward_refs()

==> dnv_bladed_models-0.3.44.tar.gz: dnv_bladed_models-0.3.44/src/dnv_bladed_models/applied_load.py <==
# coding: utf-8

from __future__ import annotations
from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra  # noqa: F401


from dnv_bladed_models.dnv import Dnv

from dnv_bladed_models.vector3_d import Vector3D


class AppliedLoad_AppliedLoadTypeEnum(str, Enum):
    TOWER_POINT_LOADING = "TowerPointLoading"
    BLADE_POINT_LOADING = "BladePointLoading"

class AppliedLoad(Dnv):
    """AppliedLoad - The common properties of a point loading time history.
    
    Attributes:
    ----------
    StartTime : float
        A number representing a time.  The SI units for time are seconds.
    LoadingFilepath : str
        A filepath or URI containing one or six degree of loading data.  In the case of the six degrees of freedom, these will be applied in the component's coordinate system.  Where a single degree of freedom is provided, SingleDirectionLoading must also be specified.
    DirectionOfLoading : Vector3D
    OnComponentInAssembly : str
        This is a JSON $ref style reference to a component in the assembly tree.
    AppliedLoadType : AppliedLoad_AppliedLoadTypeEnum
        Allows the schema to identify the type of the object.

    This class is an abstraction, with the following concrete implementations:
        BladePointLoading
        TowerPointLoading
    
    """

    StartTime: Optional[float] = Field(alias="StartTime", default=None)
    LoadingFilepath: Optional[str] = Field(alias="LoadingFilepath", default=None)
    DirectionOfLoading: Optional[Vector3D] = Field(alias="DirectionOfLoading", default=None)
    OnComponentInAssembly: Optional[str] = Field(alias="OnComponentInAssembly", default=None)
    AppliedLoadType: Optional[AppliedLoad_AppliedLoadTypeEnum] = Field(alias="AppliedLoadType", default=None)

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass

    _subtypes_ = dict()

    def __init_subclass__(cls, AppliedLoadType=None):
        cls._subtypes_[AppliedLoadType or cls.__name__.lower()] = cls

    @classmethod
    def __get_validators__(cls):
        yield cls._convert_to_real_type_

    @classmethod
    def _convert_to_real_type_(cls, data: dict):
        if isinstance(data, dict):
            data_type = data.get("AppliedLoadType")

            if data_type is None:
                raise ValueError("Missing 'AppliedLoadType' in AppliedLoad")

            sub = cls._subtypes_.get(data_type)

            if sub is None:
                raise TypeError(f"Unsupported sub-type: '{data_type}' for base-type 'AppliedLoad'")

            return sub(**data)

        return data

    @root_validator(pre=True)
    def _parsing_ignores_underscore_properties(cls, values: dict[str, any]):
        allowed_vals = {}
        for key, val in values.items():
            if not key.startswith('_'):
                if isinstance(val, dict):
                    allowed_child_vals = {}
                    for child_key, child_val in val.items():
                        if not child_key.startswith('_'):
                            allowed_child_vals[child_key] = child_val
                    allowed_vals[key] = allowed_child_vals
                else:
                    allowed_vals[key] = val
        return allowed_vals

    @validator("OnComponentInAssembly")
    def OnComponentInAssembly_pattern(cls, value):
        if value is not None and not re.match(r"^#(\/.+)+$", value):
            raise ValueError(f"OnComponentInAssembly did not match the expected format (found {value})")
        return value

    def to_json(
        self,
        *, 
        include: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        exclude: Optional[Union['AbstractSetIntStr', 'MappingIntStrAny']] = None, 
        by_alias: bool = True, 
        skip_defaults: Optional[bool] = None, 
        exclude_unset: bool = False, 
        exclude_defaults: bool = False, 
        exclude_none: bool = True, 
        encoder: Optional[Callable[[Any], Any]] = None, 
        models_as_dict: bool = True, 
        **dumps_kwargs: Any) -> str:

        r"""
        Generates a JSON string representation of the model.
        
        Notes
        -----
        `include` and `exclude` arguments as per `dict()`.

        `encoder` is an optional function to supply as `default` to json.dumps(), other arguments as per `json.dumps()`.

        Examples
        --------
        >>> model.to_json()

        Renders the full JSON representation of the model object.
        """

        if dumps_kwargs.get('indent') is None:
            dumps_kwargs.update(indent=2)

        return super().json(
                include=include, 
                exclude=exclude, 
                by_alias=by_alias, 
                skip_defaults=skip_defaults, 
                exclude_unset=exclude_unset, 
                exclude_defaults=exclude_defaults, 
                exclude_none=exclude_none, 
                encoder=encoder, 
                models_as_dict=models_as_dict, 
                **dumps_kwargs)
    
    @classmethod
    def from_file(
        cls: Type['Model'],
        path: Union[str, Path]) -> 'Model':
        
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        AppliedLoad
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = AppliedLoad.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)
    
    @classmethod
    def from_json(
        cls: Type['Model'],
        b: StrBytes) -> 'Model':

        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        AppliedLoad
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = AppliedLoad.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
    
    @classmethod
    def from_dict(
        cls: Type['Model'],
         obj: Any) -> 'Model':

        r"""
        Creates a model object from a dict.

        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        AppliedLoad
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)
    
    def to_file(
        self,
        path: Union[str, Path]):

        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.        

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')

        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())

AppliedLoad.update_forward_refs()
